@@ -1,4 +1,4 @@
-# $Id: MeCab.pm 3 2006-05-02 02:29:14Z daisuke $
+# $Id: MeCab.pm 9 2006-05-03 17:40:54Z daisuke $
 #
 # Copyright (c) 2006 Daisuke Maki <dmaki@cpan.org>
 # All rights reserved.
@@ -8,7 +8,7 @@ use strict;
 use vars qw($VERSION @ISA %EXPORT_TAGS @EXPORT_OK);
 BEGIN
 {
-    $VERSION = '0.02';
+    $VERSION = '0.05';
     if ($] > 5.006) {
         require XSLoader;
         XSLoader::load(__PACKAGE__, $VERSION);
@@ -28,7 +28,18 @@ BEGIN
 sub new
 {
     my $class = shift;
-    return (ref($_[0]) eq 'HASH') ? $class->_new(@_) : $class->_new_optarg(\@_);
+    my @args;
+    if (ref($_[0]) ne 'HASH') {
+        @args = @_;
+    } else {
+        my %args = %{$_[0]};
+        while (my ($key, $value) = each %args) {
+            $key =~ s/_/-/g;
+            push @args, "--$key=$value";
+        }
+    }
+
+    return $class->xs_new(\@args);
 }
 
 1;
@@ -54,7 +65,7 @@ Text::MeCab - Alternate Interface To libmecab
     unk_format         => $unk_format,
     bos_format         => $bos_format,
     eos_format         => $eos_format,
-    input_buffer_size  => $input_buffer_soap,
+    input_buffer_size  => $input_buffer_size,
     allocate_sentence  => $allocate_sentence,
     nbest              => $nbest,
     theta              => $theta,
@@ -67,11 +78,14 @@ Text::MeCab - Alternate Interface To libmecab
 
   # use constants
   use Text::MeCab qw(:all);
-  use Text::MeCab qw(MECAB_NODE_NODE);
+  use Text::MeCab qw(MECAB_NOR_NODE);
 
   # want to use a command line arguments?
   my $mecab = Text::MeCab->new("--userdic=/foo/bar/baz", "-P");
 
+  # check what mecab version we compiled against?
+  print "Compiled with ", &Text::MeCab::MECAB_VERSION, "\n";
+
 =head1 DESCRIPTION
 
 libmecab (http://mecab.sourceforge.ne.jp) already has a perl interface built 
@@ -126,7 +140,34 @@ details about each option.
 
 =head2 parse SCALAR
 
-Parses the given text via mecab, and returns a mecab node object.
+Parses the given text via mecab, and returns a Text::MeCab::Node object.
+
+=head1 NOTES ABOUT PARSED STRUCTURE
+
+Please note that Text::MeCab::parse() creates Text::MeCab::Node objects that 
+are C<detatched> from libmecab Tagger. This is to allow these Perl-ish idioms:
+
+  my $node;
+  {
+     my $mecab = Text::MeCab->new;
+     $node = $mecab->parse($text);
+     # $mecab goes out of scope
+  }
+
+  for(; $node; $node = $node->next) {
+     print $node->surface, "\n";
+  }
+
+and,
+
+  my $mecab  = Text::MeCab->new;
+  my $node_A = $mecab->parse($text_A);
+  my $node_B = $mecab->parse($text_B);
+
+If we are to use the mecab nodes directly we would have to carefully control
+the scope between the mecab tagger object and the nodes. Since this is perl,
+I chose maniplexity over efficiency. Let me know if there are problems with
+this approach.
 
 =head1 SEE ALSO
 
